OrmProjectContext class

Context for a resolved ORM project, containing the root directory and config file.

Constructors

OrmProjectContext({required Directory root, File? configFile})

Properties

configFile File?
final
hasConfigFile bool
no setter
hashCode int
The hash code for this object.
no setterinherited
root Directory
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited